aboutsummaryrefslogtreecommitdiff
path: root/common/system.h
diff options
context:
space:
mode:
authorMax Horn2003-07-22 20:29:06 +0000
committerMax Horn2003-07-22 20:29:06 +0000
commitd15039d2e4f63a1c8c3cefe64bc8e8bb4364aa77 (patch)
treec8be8ea9eb5c6f66ed8b1c77de249f79b908cbdf /common/system.h
parent9bd7cdbce04fafcd823c9aee31a00ee16235af81 (diff)
downloadscummvm-rg350-d15039d2e4f63a1c8c3cefe64bc8e8bb4364aa77.tar.gz
scummvm-rg350-d15039d2e4f63a1c8c3cefe64bc8e8bb4364aa77.tar.bz2
scummvm-rg350-d15039d2e4f63a1c8c3cefe64bc8e8bb4364aa77.zip
fixed play_cdrom docs
svn-id: r9131
Diffstat (limited to 'common/system.h')
-rw-r--r--common/system.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/common/system.h b/common/system.h
index 357a512d68..34b9275079 100644
--- a/common/system.h
+++ b/common/system.h
@@ -285,12 +285,12 @@ public:
/**
* Start audio CD playback.
* @param track the track to play.
* @param num_loops how often playback should be repeated (-1 = infinitely often).
* @param start_frame the frame at which playback should start.
* @param end_frame the frame at which playback should end.
*/
- virtual void play_cdrom(int track, int num_loops, int start_frame, int end_frame) = 0;
+ virtual void play_cdrom(int track, int num_loops, int start, int duration) = 0;
/**
// Stop audio CD playback
@@ -285,12 +285,12 @@ public:
/**
* Start audio CD playback.
- * @param track the track to play.
- * @param num_loops how often playback should be repeated (-1 = infinitely often).
- * @param start_frame the frame at which playback should start.
- * @param end_frame the frame at which playback should end.
+ * @param track the track to play.
+ * @param num_loops how often playback should be repeated (-1 = infinitely often).
+ * @param start the frame at which playback should start (75 frames = 1 second).
+ * @param duration the number of frames to play.
*/